# R code for statistical analyses in Campbell and Holdo 2017
# Competitive response of savanna tree seedlings to C4 grasses is negatively related to photosynthesis rate
rm(list=ls(all=TRUE))
library(nlme)
dat <- read.csv("Morphology_data.csv")
licor <- read.csv("LICOR_data.csv")
# Overall effects
dat <- subset(dat, SP != 'Grass')
mod.S <- lme(log(S) ~ TRT, data=dat, random = ~ 1 | SP)
dat2 <- subset(dat, !is.na(M))
mod.M <- lme(log(M) ~ TRT, data=dat2, random = ~ 1 | SP)
mod.RMR <- lme(log(RMR) ~ TRT, data=dat2, random = ~ 1 | SP)
# Species-specific effects
dat.tree <- aggregate(cbind(RMR,M,S) ~ SP + TRT, data=dat, mean)
dat.licor <- aggregate(cbind(A,gs) ~ SP, data=licor, mean)
# Calculate relative grass effect per species
dat.tree.T <- subset(dat.tree, TRT=='T')
dat.tree.TG <- subset(dat.tree, TRT=='TG')
dat.tree.final <- merge(dat.tree.T,dat.tree.TG,by="SP")
dat.tree.final <- dat.tree.final[,-c(2,6)]
names(dat.tree.final)[2:7] <- c("RMR.T","M.T","S.T","RMR.TG","M.TG","S.TG")
dat.tree.final$RMRratio <- dat.tree.final$RMR.TG / dat.tree.final$RMR.T
dat.tree.final$Mratio <- dat.tree.final$M.TG / dat.tree.final$M.T
dat.tree.final$Sratio <- dat.tree.final$S.TG / dat.tree.final$S.T
final <- merge(dat.tree.final,dat.licor,by="SP")
summary(lm(log(Mratio) ~ A, data=final))
summary(lm(log(Mratio) ~ gs, data=final))
summary(lm(log(Mratio) ~ log(M.T), data=final))
summary(lm(log(Sratio) ~ A, data=final))
summary(lm(log(Sratio) ~ gs, data=final))
summary(lm(log(Sratio) ~ log(S.T), data=final))